@@ -18,7 +18,10 @@ function setup_openstack_clients {
         packages+=(python-ironicclient python-ironic-inspector-client)
     fi
     if [[ $SCENARIO == magnum ]]; then
-        packages+=(python-designateclient python-magnumclient python-octaviaclient)
+        packages+=(python-designateclient python-magnumclient python-troveclient)
+    fi
+    if [[ $SCENARIO == octavia ]]; then
+        packages+=(python-octaviaclient)
     fi
     if [[ $SCENARIO == masakari ]]; then
         packages+=(python-masakariclient)
@@ -26,6 +29,9 @@ function setup_openstack_clients {
     if [[ $SCENARIO == scenario_nfv ]]; then
         packages+=(python-tackerclient python-barbicanclient python-mistralclient)
     fi
+    if [[ $SCENARIO == monasca ]]; then
+        packages+=(python-monascaclient)
+    fi
     if [[ $SCENARIO == ovn ]]; then
         packages+=(python-octaviaclient)
     fi
@@ -43,12 +49,12 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO != "bifrost" ]]; then
-        GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^chrony,^heat,^placement"
+        GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^heat,^placement"
     else
         GATE_IMAGES="bifrost"
     fi
 
-    if [[ $SCENARIO == "ceph-ansible" ]]; then
+    if [[ $SCENARIO == "cephadm" ]]; then
         GATE_IMAGES+=",^cinder"
     fi
 
@@ -66,10 +72,13 @@ function prepare_images {
         GATE_IMAGES+=",^dnsmasq,^ironic,^iscsid"
     fi
     if [[ $SCENARIO == "magnum" ]]; then
-        GATE_IMAGES+=",^designate,^magnum,^octavia"
+        GATE_IMAGES+=",^designate,^magnum,^trove"
+    fi
+    if [[ $SCENARIO == "octavia" ]]; then
+        GATE_IMAGES+=",^octavia"
     fi
     if [[ $SCENARIO == "masakari" ]]; then
-        GATE_IMAGES+=",^masakari"
+        GATE_IMAGES+=",^masakari-,^hacluster-"
     fi
 
     if [[ $SCENARIO == "swift" ]]; then
@@ -88,6 +97,10 @@ function prepare_images {
         GATE_IMAGES="^cron,^elasticsearch,^fluentd,^grafana,^haproxy,^keepalived,^kibana,^kolla-toolbox,^mariadb,^memcached,^prometheus,^rabbitmq"
     fi
 
+    if [[ $SCENARIO == "monasca" ]]; then
+        # FIXME(mgoddard): No need for OpenStack core images.
+        GATE_IMAGES+=",^elasticsearch,^grafana,^influxdb,^kafka,^kibana,^logstash,^monasca,^storm,^zookeeper"
+    fi
     sudo tee -a /etc/kolla/kolla-build.conf <<EOF
 [profiles]
 gate = ${GATE_IMAGES}
@@ -95,7 +108,7 @@ EOF
 
     mkdir -p /tmp/logs/build
 
-    sudo docker run -d -p 4000:5000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
+    sudo docker run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
 
     python3 -m venv ~/kolla-venv
     . ~/kolla-venv/bin/activate
